You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@jackrabbit.apache.org by ju...@apache.org on 2009/12/15 17:21:25 UTC

svn commit: r890865 - /jackrabbit/trunk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/commons/JcrUtils.java

Author: jukka
Date: Tue Dec 15 16:21:25 2009
New Revision: 890865

URL: http://svn.apache.org/viewvc?rev=890865&view=rev
Log:
JCR-2439: More utility methods in JcrUtils

Include the full node path in the JcrUtils.toString(Node) output.

Modified:
    jackrabbit/trunk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/commons/JcrUtils.java

Modified: jackrabbit/trunk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/commons/JcrUtils.java
URL: http://svn.apache.org/viewvc/jackrabbit/trunk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/commons/JcrUtils.java?rev=890865&r1=890864&r2=890865&view=diff
==============================================================================
--- jackrabbit/trunk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/commons/JcrUtils.java (original)
+++ jackrabbit/trunk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/commons/JcrUtils.java Tue Dec 15 16:21:25 2009
@@ -537,7 +537,7 @@
      * <p>
      * The returned string is not meant to be parsed and the exact contents
      * can change in future releases. The current string representation of
      * a node is "name [type]" and the representation of a property is
      * "@name = value(s)". Binary values are expressed like "&lt;123 bytes&gt;"
      * and other values as their standard binary representation. Multi-valued
      * properties have their values listed in like "[ v1, v2, v3, ... ]". No
@@ -551,7 +551,7 @@
         StringBuilder builder = new StringBuilder();
         try {
             if (item.isNode()) {
-                builder.append(item.getName());
+                builder.append(item.getPath());
                 builder.append(" [");
                 builder.append(((Node) item).getPrimaryNodeType().getName());
                 builder.append("]");
@@ -537,7 +537,7 @@
      * The returned string is not meant to be parsed and the exact contents
      * can change in future releases. The current string representation of
-     * a node is "name [type]" and the representation of a property is
+     * a node is "path [type]" and the representation of a property is
      * "@name = value(s)". Binary values are expressed like "&lt;123 bytes&gt;"
      * and other values as their standard binary representation. Multi-valued